@@ -126,7 +126,8 @@ function inspector_iniset {
 
 function install_inspector {
     setup_develop $IRONIC_INSPECTOR_DIR
-
+    # Check if things look okay
+    ironic-inspector-status upgrade check
     if [[ "$IRONIC_INSPECTOR_STANDALONE" == "False" ]]; then
         install_apache_wsgi
         # NOTE(rpittau) since devstack doesn't install test-requirements
@@ -153,7 +154,7 @@ function start_inspector {
     if [[ "$IRONIC_INSPECTOR_STANDALONE" == "True" ]]; then
         run_process ironic-inspector "$IRONIC_INSPECTOR_CMD"
     else
-      run_process ironic-inspector-api "$IRONIC_INSPECTOR_BIN_DIR/uwsgi --procname-prefix ironic-inspector-api --ini $IRONIC_INSPECTOR_UWSGI_CONF --pyargv \"--config-file $IRONIC_INSPECTOR_CONF_FILE\""
+      run_process ironic-inspector-api "$(which uwsgi) --procname-prefix ironic-inspector-api --ini $IRONIC_INSPECTOR_UWSGI_CONF --pyargv \"--config-file $IRONIC_INSPECTOR_CONF_FILE\""
       run_process ironic-inspector-conductor "$IRONIC_INSPECTOR_CMD_CONDUCTOR"
     fi
 
@@ -319,7 +320,6 @@ function configure_inspector {
     configure_auth_token_middleware $IRONIC_INSPECTOR_CONF_FILE $IRONIC_INSPECTOR_ADMIN_USER $IRONIC_INSPECTOR_AUTH_CACHE_DIR/api
 
     inspector_iniset DEFAULT listen_port $IRONIC_INSPECTOR_PORT
-    inspector_iniset DEFAULT listen_address 0.0.0.0  # do not change
 
     inspector_iniset pxe_filter driver $IRONIC_INSPECTOR_DHCP_FILTER
     inspector_iniset iptables dnsmasq_interface $IRONIC_INSPECTOR_INTERFACE
@@ -336,7 +336,7 @@ function configure_inspector {
     if [[ "$IRONIC_INSPECTOR_STANDALONE" == "False" ]]; then
       # memcached listens localhost instead of $SERVICE_HOST, which is exactly the default value,
       # but set explicitly in case that changed.
-      inspector_iniset coordination backend_url "memcached://localhost:11211"
+      inspector_iniset coordination backend_url "memcached://127.0.0.1:11211"
     fi
 
     if is_service_enabled swift; then
