@@ -21,8 +21,8 @@ from ironic_inspector import policy as inspector_policy
 
 CONF = cfg.CONF
 
-policy_data = """{
-}
+policy_data = """
+---
 """
 
 
@@ -31,7 +31,7 @@ class PolicyFixture(fixtures.Fixture):
         super(PolicyFixture, self).setUp()
         self.policy_dir = self.useFixture(fixtures.TempDir())
         self.policy_file_name = os.path.join(self.policy_dir.path,
-                                             'policy.json')
+                                             'policy.yaml')
         with open(self.policy_file_name, 'w') as policy_file:
             policy_file.write(policy_data)
         policy_opts.set_defaults(CONF)
